<?php

namespace Drupal\entity_sync\FieldTransformer;

use Drupal\Component\Plugin\ConfigurableInterface;
use Drupal\Component\Plugin\DependentPluginInterface;
use Drupal\Component\Plugin\PluginInspectionInterface;
use Drupal\Core\Entity\ContentEntityInterface;

/**
 * Provides the interface for field transformer plugins.
 *
 * Field transformer plugins are responsible for converting field values between
 * local and remote entities.
 *
 * @I Support exporting values in field transformer plugins
 *    type     : feature
 *    priority : normal
 *    labels   : export, field-transformer
 * @I Support validating values in field transformer plugins
 *    type     : imrpovement
 *    priority : normal
 *    labels   : export, field-transformer, validation
 */
interface PluginInterface extends
  ConfigurableInterface,
  PluginInspectionInterface,
  DependentPluginInterface {

  /**
   * Transforms the remote field value and stores it to the local field.
   *
   * Implementations must store the value to the local entity field after
   * transforming the value of the remote entity field. This is not done by the
   * field manager because all values are potentially valid, including NULL, and
   * we want to keep open the possibility that the field handler aborts the
   * field import altogether i.e. do nothing and keep the current local field
   * value as is.
   *
   * @param object $remote_entity
   *   The remote entity.
   * @param \Drupal\Core\Entity\ContentEntityInterface $local_entity
   *   The local entity.
   * @param array $field_info
   *   The field info.
   *   See \Drupal\entity_sync\Import\Event\FieldMapping::fieldMapping.
   * @param array $context
   *   An associative array containing context related to the circumstances of
   *   the operation.
   */
  public function import(
    \stdClass $remote_entity,
    ContentEntityInterface $local_entity,
    array $field_info,
    array $context
  );

}
